pub fn install(window: &WebviewWindow<Wry>)Expand description
Installs the debug server and stores a reference to the webview window. This function should be called once during app setup in debug builds.
pub fn install(window: &WebviewWindow<Wry>)Installs the debug server and stores a reference to the webview window. This function should be called once during app setup in debug builds.